@@ -1,8 +1,6 @@
 #include "MonthPlug.h"
 
 #include <QGridLayout>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
 
 #include <QAction>
 #include <QPainter>
@@ -15,7 +13,6 @@
 #include "WeekButton.h"
 
 #include "ChangeManager.h"
-
 #include "Date.h"
 
 using namespace Metrics::MonthWidget;
@@ -27,8 +24,8 @@ MonthPlug::MonthPlug(QDate date, QWidget *parent) :
     this->date = fromGlobalDate(date);
 
     QGridLayout *mainLayout = new QGridLayout(this);
-    QHBoxLayout *dayLayout  = new QHBoxLayout();
     weekLayout = new QVBoxLayout();
+    dayLayout  = new QHBoxLayout();
 
     mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->setSpacing(0);
@@ -47,7 +44,7 @@ MonthPlug::MonthPlug(QDate date, QWidget *parent) :
     font.setPointSize(13);
     font.setBold(true);
     for (int i = 0; i < NumWeekdays; i++) {
-        QLabel *dayLabel = new QLabel(QLocale().standaloneDayName(i+1, QLocale::ShortFormat));
+        QLabel *dayLabel = new QLabel();
         dayLabel->setAlignment(Qt::AlignCenter);
         dayLabel->setFixedWidth(CellWidth);
         dayLabel->setFont(font);
@@ -59,7 +56,7 @@ MonthPlug::MonthPlug(QDate date, QWidget *parent) :
     mainLayout->addLayout(weekLayout, 1, 0);
     mainLayout->addWidget(monthWidget, 1, 1);
 
-    // Se up menu actions
+    // Set up menu actions
     QAction *prevAction = new QAction(tr("Previous month"), this);
     QAction *nextAction = new QAction(tr("Next month"), this);
     QAction *todayAction = new QAction(tr("Jump to today"), this);
@@ -94,6 +91,10 @@ QString MonthPlug::title() const
 
 void MonthPlug::onChange()
 {
+    // Set day names
+    for (int i = 0; i < NumWeekdays; i++)
+        static_cast<QLabel*>(dayLayout->itemAt(i)->widget())->setText(QLocale().standaloneDayName(Date::absDayOfWeek(i+1), QLocale::ShortFormat));
+
     setDate(currentDateLock ? QDate::currentDate() : this->globalDate());
 }
 
@@ -194,5 +195,5 @@ QDate MonthPlug::toGlobalDate(QDate date)
 
 QDate MonthPlug::fromGlobalDate(QDate globalDate)
 {
-    return globalDate.addDays(1 - globalDate.day());;
+    return globalDate.addDays(1 - globalDate.day());
 }
