@@ -73,7 +73,7 @@ void ComponentWidget::paintEvent(QPaintEvent *)
     painter.setPen(QMaemo5Style::standardColor("ReversedTextColor"));
 
     const bool alarm = component->getAlarm();
-    const QString summary = QString::fromUtf8(component->getSummary().c_str());
+    const QString summary = CWrapper::summary(component, QDateTime::fromTime_t(instance->stamp).date());
 
     if (component->getAllDay() || component->getType() != E_EVENT) {
         // All-day event or not an event
@@ -179,6 +179,7 @@ void ComponentWidget::contextMenuEvent(QContextMenuEvent *e)
     QMenu *contextMenu = new QMenu(this);
     contextMenu->setAttribute(Qt::WA_DeleteOnClose);
     contextMenu->addAction(tr("Edit"), this, SLOT(editComponent()));
+    contextMenu->addAction(tr("Clone"), this, SLOT(cloneComponent()));
     contextMenu->addAction(tr("Delete"), this, SLOT(deleteComponent()));
     contextMenu->exec(e->globalPos());
 }
@@ -273,6 +274,11 @@ void ComponentWidget::editComponent()
     ChangeManager::edit(this, instance->component);
 }
 
+void ComponentWidget::cloneComponent()
+{
+    ChangeManager::clone(this, instance->component);
+}
+
 void ComponentWidget::deleteComponent()
 {
     ChangeManager::drop(this, instance->component);
